# Decorative Image

The **Decorative Image** module allows content editors to mark images as decorative, ensuring they are ignored by assistive technologies like screen readers. It integrates a "Decorative image" checkbox into image fields, allowing for easy accessibility improvements.

## Features
- Adds a `Decorative image` checkbox to image field widgets.
- Applies `role="presentation"` to marked images for improved accessibility.
- Can be enabled per image field via `Manage Form Display` in the frontend.
- Stores decorative status persistently using Drupal’s key-value storage.

## Installation & Usage

### Installation
```sh
composer require drupal/decorative_image
drush en -y decorative_image
```

### Configuration

1.  Navigate to **Manage Form Display** for an image field.

2.  Enable the **"Decorative image"** option in the field widget settings.


### Usage

*   When adding or editing an image, check **\[X\] Decorative image** to apply the decorative role.


Technical Notes
---------------

*   To customize how images are processed, refer to these additional functions:
  * template_preprocess_image()
  * template_preprocess_image_formatter()
  * template_preprocess_responsive_image_formatter()


Accessibility Benefits
----------------------

Marking non-informative images as decorative prevents screen readers from announcing them, reducing audible clutter. For best practices, refer to the [W3C decorative images guide](https://www.w3.org/WAI/tutorials/images/decorative/).
